A directed relationship between two nodes in an %Artefact{} graph.
%Artefact{}
type is a single CamelCase or SCREAMING_SNAKE_CASE string (Neo4j has no multi-label relationships). from_id and to_id reference node id fields within the same graph.
type
from_id
to_id
id
@type t() :: %Artefact.Relationship{ from_id: String.t(), id: String.t(), properties: map(), to_id: String.t(), type: String.t() }